SOC = {}

SOC.feePercentage = 0.25

SOC.options = {
	{text = "$1,000,000", amount = 1000000},
	{text = "$10,000,000", amount = 10000000},
	{text = "$100,000,000", amount = 100000000},
	{text = "$1,000,000,000", amount = 1000000000},
	{text = "$10,000,000,000", amount = 10000000000},
}

SOC.menu = CustomMenuClass:new({
	panelGaps = 0,
	hasLoading = false,
	hasBorder = false
})

SOC.menuLoaded = false

function SOC.feeCalculation(amount)
	return math.round(amount * SOC.feePercentage)
end

function SOC.convertSpendingToOffshore(amount)
	if not SOC.hasEnoughSpending(amount) then
		return
	end
	local fees = SOC.feeCalculation(amount)
	managers.money:deduct_from_spending(amount)
	managers.money:add_to_offshore(amount - fees)
	SOC.saveAndRefresh()
end

function SOC.convertOffshoreToSpending(amount)
	if not SOC.hasEnoughOffshore(amount) then
		return
	end
	local fees = SOC.feeCalculation(amount)
	managers.money:deduct_from_offshore(amount)
	managers.money:add_to_spending(amount - fees)
	SOC.saveAndRefresh()
end

function SOC.hasEnoughSpending(amount)
	return managers.money:total() >= amount
end

function SOC.hasEnoughOffshore(amount)
	return managers.money:offshore() >= amount
end

function SOC.saveAndRefresh()
	if managers.savefile then
		managers.savefile:save_progress()
	end
	if managers.menu_component then
		managers.menu_component:refresh_player_profile_gui()
	end
	SOC.loadMenu()
	SOC.menu:refreshMenu()
end

function SOC.loadMenu()
	SOC.menu:addMainMenu("main_menu", {title = "Spending Offshore Converter"})
	
	SOC.menu:addInformationOption("main_menu", "Spending to Offshore :")
	SOC.menu:addGap("main_menu")
	for _, option in pairs(SOC.options) do
		if SOC.hasEnoughSpending(option.amount) then
			SOC.menu:addOption("main_menu", option.text, {
				help = "Convert " .. option.text .. " spending to offshore.",
				callback = SOC.convertSpendingToOffshore,
				callbackData = option.amount
			})
		else
			SOC.menu:addInformationOption("main_menu", option.text, {textColor = Color.red})
		end
	end
	SOC.menu:addGap("main_menu")
	SOC.menu:addGap("main_menu")
	SOC.menu:addInformationOption("main_menu", tostring(math.round(SOC.feePercentage * 100)) .. "% fees will be applied to each transaction !", {textColor = Color.yellow})
	
	SOC.menu:addInformationOption("main_menu", "Offshore to Spending :")
	SOC.menu:addGap("main_menu")
	for _, option in pairs(SOC.options) do
		if SOC.hasEnoughOffshore(option.amount) then
			SOC.menu:addOption("main_menu", option.text, {
				help = "Convert " .. option.text .. " offshore to spending.",
				callback = SOC.convertOffshoreToSpending,
				callbackData = option.amount
			})
		else
			SOC.menu:addInformationOption("main_menu", option.text, {textColor = Color.red})
		end
	end
end